<?
########## Confixx(R) 3.0 Professional ############
####### Copyright SWsoft, Inc. 2004-2005 ##########
#### http://www.sw-soft.com - info@sw-soft.com ####

include_once("auth.php");
db_connect($db_host, $db_user, $db_pass);

global $DEBUG;
//$DEBUG=1;

$loUser = new SQLString($PHP_AUTH_USER);
$indexcode = str_replace(chr(174), '&reg;', $indexcode);
$indexcode = str_replace(chr(169), '&copy;', $indexcode);

safe_query2( "UPDATE anbieter SET indexcode = ?, indexfile = ?".
						 " WHERE anbieter = ? AND server_id='$ServerID'", new SQLString($indexcode),
						 new SQlString($indexfile), $loUser );

if( $oldindexfile != $indexfile ){ ## force reconfigure apache
	safe_query2( "UPDATE kunden SET httpd=1 WHERE anbieter=? AND server_id='$ServerID'", $loUser);
	safe_query2( "UPDATE allgemein SET httpd=1 WHERE server_id='$ServerID'" );
 }

$fehlertitel = ltext("kuin2_errortitle");
$fehlertext = ltext("kuin2_error1");
db_close();
include("kunden_index.php");
exit();
?>
